{ ****************************************************************** }
{                                                                    }
{   Delphi component TMoneyPanel                                     }
{   on 17 March 1998 at 8:52                                         }
{   Copyright  1998 by Michael Tran                                 }
{                                                                    }
{ ****************************************************************** }

unit Moneybar;

interface

uses WinTypes, WinProcs, Messages, SysUtils, Classes, Controls,
     Graphics,StdCtrls, ExtCtrls, menus, dialogs;

type
  TMoneyPanel = class(TCustompanel)
    private
        FBevelWidth : integer;
        TempB : tBitmap;
        FFbitmap : TBitmap;
        Fcolor : tcolor;
        F3D : boolean;
        FShadow: boolean;
        FDropDown: TPopupMenu;
        Fborder : boolean;
        falignment : Talignment;
        procedure AutoInitialize;
        { Method to free any objects created by AutoInitialize }
        procedure AutoDestroy;
        { Write method for property Fbitmap }
        procedure SetFbitmap(Value : TBitmap);
        procedure SetColor(Value : Tcolor);
        Procedure Set3D(value:boolean);
        procedure SetShadow(value:boolean);
        procedure SetFBevelWidth(value:integer);
        procedure SetDropDown(value: TPopupMenu);
        Procedure Setborder(value:boolean);
    protected
        mx,my:integer;
        procedure Click; override;
        procedure Loaded; override;
        procedure Paint; override;
        procedure DrawPopupMark(x, y: Integer);
        procedure MouseMove(Shift: TShiftState; X, Y: Integer); override;
{        function GetPalette: HPALETTE; override;}
    public
      { Public fields of TMoneyPanel }

      { Public methods of TMoneyPanel }
        constructor Create(AOwner: TComponent); override;
        destructor Destroy; override;

    published
      { Published properties of the component }
        property Caption;
        Property Border: boolean read Fborder write Setborder;
        property Align;
        Property Color: Tcolor read Fcolor write Setcolor default clbtnface;
        Property Font;
        Property Font3D: boolean read F3d write Set3d default false;
        Property Shadow: boolean read Fshadow write SetShadow default false;
        Property Alignment: Talignment  read falignment write falignment default taLeftJustify;
        property DropDownMenu: TPopupMenu read FDropDown write SetDropDown stored True;
        Property BevelWidth : integer read FBevelWidth write SetFBevelWidth default 1;
        property OnClick;
        property OnDblClick;
        property OnDragDrop;
        property OnMouseDown;
        property OnMouseMove;
        property OnMouseUp;
        Property Visible;
        property Pattern : TBitmap read FFbitmap write SetFbitmap;

  end;

procedure Register;

implementation
const
   bmBits: Array[0..7] of Integer=($AA,$55,$AA,$55,$AA,$55,$AA,$55);
procedure Register;
begin
     RegisterComponents('Samples', [TMoneyPanel]);
end;

{ Method to set variable and property values and create objects }
procedure TMoneyPanel.AutoInitialize;
begin

     FFbitmap := TBitmap.Create;
     TempB  := TBitmap.Create;
     TempB.handle := CreateBitmap(8, 8, 1, 1, @bmBits[0]);
     ControlStyle := ControlStyle - [csOpaque];
     Fcolor := clbtnface;
     alignment := taLeftJustify;
     FBevelWidth := 1;
end; { of AutoInitialize }

(*function TMoneyPanel.GetPalette: HPALETTE;
begin
  Result := 0;	{ default result is no palette }
  Result := TBitmap(FFBitmap).Palette;	{ use it if available }
end; *)

procedure TMoneyPanel.SetDropDown(value: TPopupMenu);
begin
if value.items.count = 0 then
begin
 showmessage('Cannot assign empty menu');
 exit;
end;
	FDropDown := value;
refresh;
end;


procedure TMoneyPanel.AutoDestroy;
begin

     FFbitmap.Free;
     deleteobject(TempB.handle);
     tempB.free;
end; { of AutoDestroy }
procedure TMoneyPanel.Setborder(value:boolean);
begin
fborder := value;
paint;
end;

procedure TMoneyPanel.SetColor(Value : Tcolor);
begin
  Fcolor := value;
  paint;
end;

procedure TMoneyPanel.SetFBevelWidth(value:integer);
begin
 FBevelWidth := value;
 paint;
end;
procedure TMoneyPanel.SetShadow(value:boolean);
begin
 Fshadow := value;
 paint;
end;

procedure TMoneyPanel.Set3D(value:boolean);
begin
 f3d := value;
 paint;
end;

procedure TMoneyPanel.SetFbitmap(Value : TBitmap);
begin
     { Use Assign method because TBitmap is an object type }
     FFbitmap.Assign(Value);
     Paint;
end;

{ Override OnClick handler from TCustomPanel }
procedure TMoneyPanel.Click;
var    x,y : integer;
       t : tpoint;
begin
y :=  height div 2;
if assigned(FDropDown) then
  begin
     case alignment of
       taLeftJustify: x:= 5;
       taRightJustify: x:= (width - canvas.textwidth(caption)) - 15;
       taCenter: x:= ((width - canvas.textwidth(caption)) div 2) - 5;
     end;
     t:= ClientToScreen(point(0,height));
   if (mx >= x) and (mx <= x + 10 ) and (my >= y - 5) and (my <= y + 5) then
          FDropDown.popup(t.x,t.y);
  end
 else
   inherited Click;

end;

procedure TMoneyPanel.MouseMove(Shift: TShiftState; X, Y: Integer);
begin
mx:=x;
my:= y;
inherited mousemove(Shift, X, Y);
end;

constructor TMoneyPanel.Create(AOwner: TComponent);
begin
     { Call the Create method of the container's parent class       }
     inherited Create(AOwner);

     AutoInitialize;

     { Code to perform other tasks when the container is created    }

end;

procedure TMoneyPanel.DrawPopupMark(x, y: Integer);
var theColor: TColor;
begin
  theColor := Canvas.Font.Color;
  canvas.pen.color := theColor;
  canvas.pen.style := psSolid;
  if x < 5 then x := 5;
  canvas.moveto(x,y-1);
  canvas.lineto(x+6,y-1);
  canvas.moveto(x,y);
  canvas.lineto(x+6,y);
  canvas.moveto(x,y);
  canvas.lineto(x+6,y);
  canvas.moveto(x+1,y+1);
  canvas.lineto(x+5,y+1);
  canvas.moveto(x+2,y+2);
  canvas.lineto(x+4,y+2);
  canvas.moveto(x+3,y+3);
  canvas.lineto(x+4,y+3);
end;

destructor TMoneyPanel.Destroy;
begin
     AutoDestroy;
     inherited Destroy;
end;

procedure TMoneyPanel.Loaded;
begin
     inherited Loaded;

     { Perform any component setup that depends on the property
       values having been set }

end;

procedure TMoneyPanel.Paint;
var ar: trect;
    x,y : integer;
begin
 canvas.brush.style := bssolid;
if Fshadow then
 begin
   ar := rect(2,2,width,height);
   canvas.brush.bitmap := Tempb;
   Canvas.fillrect(ar);
   ar := rect(0,0,width-2,height-2);
 end
else
  ar := rect(0,0,width,height);
     if not FFbitmap.empty then
     begin
       canvas.brush.bitmap := FFbitmap;
{       PaletteChanged(false);}
     end
     else
       canvas.brush.color := Fcolor;
     Canvas.fillrect(ar);

     winprocs .SetBkMode(Canvas.Handle,wintypes .TRANSPARENT);
if not Fshadow then
     FRAME3D(Canvas,AR, clBtnHighlight,clBtnShadow,FBevelWidth)
else
 if fborder then
     FRAME3D(Canvas,AR, clBtnShadow,clBtnShadow, FBevelWidth);
     canvas.font := font;
     y:= (ar.bottom - canvas.textheight('H')) div 2;
     case alignment of
       taLeftJustify: if FDropDown <> nil then x:= 18 else x := 12;
       taRightJustify: x:= (ar.right - canvas.textwidth(caption)) - 10;
       taCenter: x:= (ar.right - canvas.textwidth(caption)) div 2;
     end;
     If f3d then
      begin
       canvas.font.color := clblack;
       canvas.textout(x+2,y+2,caption);
      if FDropDown <> nil then
        DrawPopupMark(x -(canvas.textwidth('H') div 2) -4, y + (canvas.textheight('H') div 2) + 2);
      end;
     canvas.font := font;
     if FDropDown <> nil then
       DrawPopupMark(x -(canvas.textwidth('H') div 2) -4, y + (canvas.textheight('H') div 2));
     canvas.textout(x,y,caption);
end;


end.
